from .base import Cut
from .mixed import MixedCut, MixTrack
from .mono import MonoCut
from .padding import PaddingCut
from .set import CutSet

"""
The following is the hierarchy of imports in this module (to avoid circular imports):
      ┌─────────────┐
      │ __init__.py │─────────────────────────────────┬────────────────────┐
      └─────────────┘                                 │                    │
             │                                        ▼                    │
             │                               ┌────────────────┐            │
             ├──────────────────────┬───────▶│  mono.MonoCut  │────────────┤
             │                      │        └────────────────┘            │
             │                      │                                      │
             │                      │                                      │
             │           ┌────────────────────┐                            ▼
             │           │   mixed.MixTrack   │                     ┌─────────────┐
             ├──────────▶│   mixed.MixedCut   │────────────────────▶│  base.Cut   │
             │           └────────────────────┘                     └─────────────┘
             │                      │                                      ▲
             │                      │                                      │
             │                      │                                      │
             │                      │        ┌────────────────────┐        │
             ├──────────────────────┴───────▶│ padding.PaddingCut │────────┤
             │                               └────────────────────┘        │
    ┌────────────────┐                                  ▲                  │
    │   set.CutSet   │──────────────────────────────────┴──────────────────┘
    └────────────────┘
"""

# The following functions are imported in other modules, so we need to import them here.
__all__ = [
    "create_cut_set_eager",
    "create_cut_set_lazy",
    "compute_supervisions_frame_mask",
    "append_cuts",
    "mix_cuts",
]

from .set import (
    append_cuts,
    compute_supervisions_frame_mask,
    create_cut_set_eager,
    create_cut_set_lazy,
    mix_cuts,
)
